Surfer survives ‘Jaws’ moment with great white shark | New York Post
Author: http://nypost.com/author/fox-news/
Description: A surfer survived being attacked and dragged underwater by a juvenile great white shark off the central California coast Sunday. California State Park Ranger Supervisor Robert Colligan said the att...
Date: 2014-12-29T15:32:29+00:00

### Thanks for contacting us. We've received your submission.

Back to Reading

News

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

# Surfer survives ‘Jaws’ moment with great white shark

By Fox News

- View author archive
- Get author RSS feed

Name(required)
Email(required)
Comment(required)

December 29, 2014 | 10:32am

Modal Trigger
50-year-old surfer Kevin Swanson survived being attacked and dragged underwater by a 8-to-10 foot great white shark off the coast of California on Sunday. Photo: Barcroft

### Originally published by:

### MORE ON:

###### great white sharks

##### The real 'Sharknado' is here

A surfer survived being attacked and dragged underwater by a juvenile great white shark off the central California coast Sunday.

California State Park Ranger Supervisor Robert Colligan said the attack by the 8-to-10 foot shark happened at around 11 a.m. local time at Montana de Oro State Park, approximately 200 miles northwest of Los Angeles.

The San Luis Obispo Tribune, citing witnesses, identified the surfer as 50-year-old Kevin Swanson of Morro Bay, Calif. He was airlifted to a local hospital with non-life-threatening injuries to his right hip and thigh and a hospital spokesman said Swanson was in fair condition Sunday afternoon.

Andrew Walsh, who was surfing with Swanson, told the paper that the shark swam up from underneath Swanson’s board and grabbed him with no warning. Walsh added that Swanson surfaced after several seconds, yelled “shark attack!”, and began paddling to shore.

Before Swanson got out of the water, Walsh said, he fashioned a tourniquet from his surfboard’s leash cord. Two doctors who happened to be walking on the beach at the time examined him and determined that no arteries were hit.

“We’re really blessed that he was still able to get himself to shore,” Walsh said. “I was a few feet behind him, and we grabbed him and got him … up on the sand, and very quickly these doctors were there, helping out and calling 911.”

The beach remained open, but signs will be posted for three days warning the public of the attack, Colligan said. He noted that if there is another shark sighting, the signs will remain up for another three days.

Sharks are native to the area, and Colligan said that they are spotted several times a year. He added that attacks like this are rare.

A woman swimming with seals was killed by a shark in 2003 about 10 miles south of the most recent attack, Colligan said.

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

This article originally appeared on Fox News.

Filed under Animals , California , great white sharks , Wow

### Share this:

- Share

- Facebook
- Twitter
- Google
- WhatsApp
- Email

Read Next:

Final passengers rescued… Final passengers rescued from stranded,… Final passengers rescued from stranded, burned ferry

Recommended For You
Loading, please wait...
Most Popular This Week
1
Arrests plummet 66% with NYPD in virtual work stoppage
2
Three cheers for the NYPD
3
Cops turn backs on de Blasio at executed officer’s funeral
4
‘It was rough, man': Rex Ryan speaks to cap his whirlwind day
5
Astrophysicist angers Christians with Christmas tweet
6
Passenger tossed after flipping out over staff’s ‘Merry Christmas’

Share Selection

Facebook Twitter
Send to Email Address Your Name Your Email Address Cancel
Post was not sent - check your email addresses!
Email check failed, please try again
Sorry, your blog cannot share posts by email.

# Sign Up / Sign In Sign In // Sign Up

## With your existing account from...

{* loginWidget *}

## Use an account with your email address

{* #userInformationForm *} {* traditionalSignIn_emailAddress *} {* traditionalSignIn_password *}
{* traditionalSignIn_signInButton *}{* traditionalSignIn_createButton *}
{* /userInformationForm *}

# Sign Up / Sign In Sign In // Sign Up

## Welcome Back, {* welcomeName *}

{* loginWidget *}
Use an account with your email address

# Sign Up / Sign In Sign In // Sign Up

## Welcome back!

{* welcomeName *}
{* #userInformationForm *} {* traditionalSignIn_emailAddress *} {* traditionalSignIn_password *}
{* traditionalSignIn_signInButton *}
{* /userInformationForm *}
Use an account with your email address

# Almost Done!

{* #registrationForm *} {* traditionalRegistration_emailAddress *} {* traditionalRegistration_password *} {* traditionalRegistration_passwordConfirm *} {* traditionalRegistration_displayName *} {* traditionalRegistration_captcha *} {* traditionalRegistration_ageVerification *} By clicking "Create Account", you confirm that you accept our terms of service and have read and understand privacy policy.
{* /registrationForm *}

# Create a new password Forgot
Password?

## Don't worry, it happens. We'll send you a link to create a new password.

{* #forgotPasswordForm *} {* traditionalSignIn_emailAddress *}
{* /forgotPasswordForm *}

# Create a new password Sent!

We've sent an email with instructions to create a new password. Your existing password has not been changed.

# Account Already Exists

{* mergeAccounts *}
{* backButton *}

# Sign in to complete account merge

{* #tradAuthenticateMergeForm *} {* traditionalSignIn_emailAddress *} {* mergePassword *}
{* /tradAuthenticateMergeForm *}